@@ -178,7 +178,7 @@ bool partition_info::add_named_partition(const char *part_name, size_t length)
   }
   DBUG_PRINT("info", ("Found partition %u is_subpart %d for name %.*s",
                       part_def->part_id, part_def->is_subpart,
-                      static_cast<int>(length), part_name));
+                      length, part_name));
   DBUG_RETURN(false);
 }
 
@@ -674,11 +674,11 @@ partition_element *partition_info::get_part_elem(const char *partition_name,
   Helper function to find_duplicate_name.
 */
 
-static const uchar *get_part_name_from_elem(const void *name, size_t *length,
-                                            my_bool)
+static const char *get_part_name_from_elem(const char *name, size_t *length,
+                                      my_bool not_used __attribute__((unused)))
 {
-  *length= strlen(static_cast<const char *>(name));
-  return static_cast<const uchar *>(name);
+  *length= strlen(name);
+  return name;
 }
 
 /*
@@ -716,8 +716,8 @@ char *partition_info::find_duplicate_name()
   max_names= num_parts;
   if (is_sub_partitioned())
     max_names+= num_parts * num_subparts;
-  if (my_hash_init(PSI_INSTRUMENT_ME, &partition_names, system_charset_info,
-                   max_names, 0, 0, get_part_name_from_elem, 0, HASH_UNIQUE))
+  if (my_hash_init(PSI_INSTRUMENT_ME, &partition_names, system_charset_info, max_names, 0, 0,
+                   (my_hash_get_key) get_part_name_from_elem, 0, HASH_UNIQUE))
   {
     DBUG_ASSERT(0);
     curr_name= (const uchar*) "Internal failure";
@@ -1824,7 +1824,7 @@ bool partition_info::add_column_list_value(THD *thd, Item *item)
   part_column_list_val *col_val;
   Name_resolution_context *context= &thd->lex->current_select->context;
   TABLE_LIST *save_list= context->table_list;
-  THD_WHERE save_where= thd->where;
+  const char *save_where= thd->where;
   DBUG_ENTER("partition_info::add_column_list_value");
 
   if (part_type == LIST_PARTITION &&
@@ -1838,9 +1838,9 @@ bool partition_info::add_column_list_value(THD *thd, Item *item)
 
   context->table_list= 0;
   if (column_list)
-    thd->where= THD_WHERE::FIELD_LIST;
+    thd->where= "field list";
   else
-    thd->where= THD_WHERE::PARTITION_FUNCTION;
+    thd->where= "partition function";
 
   if (item->walk(&Item::check_partition_func_processor, 0, NULL))
   {
@@ -2434,7 +2434,7 @@ bool partition_info::has_same_partitioning(partition_info *new_part_info)
       partition_element *new_part_elem= new_part_it++;
       /*
         The following must match:
-        partition_name, tablespace_name, data_file_name, index_file_name,
+        partition_name, data_file_name, index_file_name,
         engine_type, part_max_rows, part_min_rows, nodegroup_id.
         (max_value, signed_flag, has_null_value only on partition level,
         RANGE/LIST)
@@ -2520,9 +2520,7 @@ bool partition_info::has_same_partitioning(partition_info *new_part_info)
             if (strcmp_null(sub_part_elem->data_file_name,
                             new_sub_part_elem->data_file_name) ||
                 strcmp_null(sub_part_elem->index_file_name,
-                            new_sub_part_elem->index_file_name) ||
-                strcmp_null(sub_part_elem->tablespace_name,
-                            new_sub_part_elem->tablespace_name))
+                            new_sub_part_elem->index_file_name))
               DBUG_RETURN(false);
 
           } while (++j < num_subparts);
@@ -2538,9 +2536,7 @@ bool partition_info::has_same_partitioning(partition_info *new_part_info)
         if (strcmp_null(part_elem->data_file_name,
                         new_part_elem->data_file_name) ||
             strcmp_null(part_elem->index_file_name,
-                        new_part_elem->index_file_name) ||
-            strcmp_null(part_elem->tablespace_name,
-                        new_part_elem->tablespace_name))
+                        new_part_elem->index_file_name))
           DBUG_RETURN(false);
       }
     } while (++i < num_parts);
